#!/usr/bin/env python
# coding: utf-8

import glob
import os
import sys

#import amrs.misc.describe
import dplume
import smartcarb as sc


def main(tracer, show=False):
    """
    Extract time series of number of pixels for different cloud thresholds
    """
    signal_thr, cloud_thr = dplume.get_berlin_thresholds(tracer)

    description = """\
# Sentinel-7 %s time series of pixels in Berlin CO2 plumes
#
# plume: %s_BV > %f ppm
# cloud thresholds (less or equal): 1.0, 0.30, 0.05 and 0.01
# does_overlap is True if cloud-free (<= %.2f) existis over Berlin (radius: 25 km)
#
""" % (tracer, 'XCO2 'if tracer == 'CO2' else tracer, signal_thr, cloud_thr)


    # filenames
    root_path = sc.config.DATA_PATH
    path = os.path.join(root_path, 'level2',
                        'Sentinel_7_CO2')
    filenames = sorted(glob.glob(os.path.join(path, '*.nc')))

    out_filename = os.path.join(root_path, 'timeseries',
                                '%s_Berlin_plume_size.dat' % tracer)

    with open(out_filename, 'w') as out:

        # write description
        out.write(description)

        # write headers 5
        out.write('\t'.join(['date', 'orbit', 'lon_eq', 'pixels (<100%)',
                             'pixels (<30%)', 'pixels (<5%)', 'pixels (<1%)',
                             'does_overlap']))
        out.write('\n')

        for filename in filenames:
            line = dplume.show_berlin_plume(filename, tracer=tracer,
                                            save=False, signal_thr=signal_thr,
                                            cloud_thr=cloud_thr,
                                            save_pdf=False, show=False)

            if line:
                out.write(line)
                out.write('\n')



if __name__ == '__main__':
    main(sys.argv[1])













