#!/usr/bin/env python
# coding: utf-8

from multiprocessing import Pool

import glob
import os
import sys

import dplume

def get_fnames(origin, product):

    path =  "/project/kug/smartcarb/results/%s/plume_detection_mc" % origin
    print(os.path.join(path, product))
    filenames = sorted(glob.glob(
        os.path.join(path, product, "*.nc")
    ))
    return filenames


def main(tracer, ssp, q, ns):

    origin = 'Berlin'
    product = dplume.io.get_product(tracer=tracer, ssp=ssp, q=q, ns=ns,
                                    use_s5=(ssp=='S5'))

    filenames = get_fnames(origin, product)
    n = len(filenames)

    columns = ['utc', 'orbit', 'lon_eq', 'detected_pixels',
               'CO2_pixels', 'NO2_pixels']

    for label in ['all_', 'CO2_', 'NO2_',]:
        columns += [label+s for s in ['TP', 'FP', 'TN', 'FN', 'PPV']]

    out_filename = '%s.dat' % product

    with open(out_filename, 'w') as out:

        descr = '\n# '.join([
            '# Confusion matrix for plume detection with Monte Carlo experiment',
            '',
            'utc:             observation time',
            'orbit:           orbit number',
            'lon_eq:          equator starting longitude (*100)',
            'detected_pixels: number of pixels detected by the algorithm',
            'CO2_pixels:      number of valid CO2 pixels in true CO2 plume',
            'NO2_pixels:      number of valid NO2 pixels in true CO2 plume',
            '',
            'Confusion matrix:',
            'label_TP:        true positives',
            'label_FP:        false positives',
            'label_TN:        true negatives',
            'label_FN:        false negatives',
            'label_PPV:       positive predictive value',
            '',
            'Labels:',
            'all:             using all pixels from the true plume',
            'CO2:             using only valid (i.e. cloud-free) CO2 pixels',
            'NO2:             using only valid (i.e. cloud-free) NO2 pixels',
            '',
            '(a true plume are all pixels with CO2 signals from Berlin > 0.05'
            ' ppm that are connected to the source area)',
            ''
        ])

        out.write(descr)
        out.write('\n')

        out.write('\t'.join(columns))
        out.write('\n')

        for i in range(0,n,100):
            with Pool(processes=20) as pool:
                res = pool.map(dplume.extract_mc_detection, filenames[i:i+100])

            for line in res:
                #sys.stdout.write('\r')
                #sys.stdout.write(line)
                #sys.stdout.flush()

                out.write(line)
                out.write('\n')
    print()

if __name__ == '__main__':
    #main('CO2', 0.5, 0.99, 37)
    #main('CO2', 0.7, 0.99, 37)
    #main('CO2', 1.0, 0.99, 37)
    #main('NO2', 'low', 0.99, 37)
    main('NO2', 'S5', 0.99, 5)
    main('NO2', 'S5', 0.99, 9)


